mod sensors;
mod comm;
mod config;
mod external;
mod bar;
mod store;

use comm::{Channel, Message};
use config::Config;
use std::env;
use std::sync::Arc;
use std::sync::mpsc;
use std::thread;

fn main() {
    let config_path = env::args().nth(1).unwrap_or("./panel.toml".to_string());
    let cfg = config::load(&config_path);

    let mut topbar = bar::Bar::new(true, &cfg);
    let mut botbar = bar::Bar::new(false, &cfg);

    let cfg = Arc::new(cfg);
    let (tx, rx) = mpsc::channel::<Message>();
    make_thread(&tx, &cfg, external::external);
    make_thread(&tx, &cfg, sensors::sensors);

    let mut data = store::Store::new();

    loop {
        let msg = rx.recv().unwrap();
        data.save(msg);

        topbar.send(&format!("{}| {}%{{r}}{}",
            data.get("desktops"),
            data.get("title"),
            data.get("sensors")
        ));
        botbar.send(&format!("{}", data.get("cmus")));
    }
}

fn make_thread(tx: &Channel, cfg: &Arc<Config>, func: fn(&Channel, &Config) -> ()) {
    let thread_tx = tx.clone();
    let thread_cfg = cfg.clone();
    thread::spawn(move || {
        func(&thread_tx, &thread_cfg);
    });
}


