use super::Sensor;
use std::process::Command;

pub struct DiskSensor {
    mount: String,
    space: String
}

impl DiskSensor {
    pub fn new(mount: &str) -> DiskSensor {
        DiskSensor { mount: mount.to_string(), space: "".to_string() }
    }
}

impl Sensor for DiskSensor {
    fn icon(&self) -> String {
        self.mount.clone()
    }

    fn status(&self) -> String {
        self.space.clone()
    }

    fn process(&mut self) {
        let output = Command::new("df")
          .arg("--output=avail")
          .arg("-h")
          .arg(&self.mount)
          .output()
          .ok()
          .expect("Could not run df");

        let output = String::from_utf8_lossy(&output.stdout);
        let space = output.lines().nth(1).expect("Could not get space");

        self.space = space.trim().to_string()
    }
}
